==> antd-pro-toolkit-0.6.0.tgz: package/es/Timeline/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import { Timeline, Icon } from 'antd';
import './style';

var CusTimeline =
/*#__PURE__*/
function (_Component) {
  _inherits(CusTimeline, _Component);

  function CusTimeline(props) {
    _classCallCheck(this, CusTimeline);

    return _possibleConstructorReturn(this, _getPrototypeOf(CusTimeline).call(this, props));
  }

  _createClass(CusTimeline, [{
    key: "renderSteps",
    value: function renderSteps(steps) {
      var timelineDot = function timelineDot(index) {
        if (index === 0) {
          return React.createElement("span", {
            className: "dotfirst"
          }, React.createElement(Icon, {
            type: "check"
          }));
        } else {
          return React.createElement("span", {
            className: "dots"
          });
        }
      };

      return steps.map(function (item, index) {
        return React.createElement(Timeline.Item, {
          key: index,
          dot: timelineDot(index)
        }, item.year && React.createElement("div", {
          className: "week"
        }, item.year, "\xA0", item.week), React.createElement("span", {
          className: "messageTime"
        }, item.messageTime), React.createElement("span", {
          className: "statusName"
        }, item.curStatus), React.createElement("span", {
          className: "message"
        }, item.message));
      });
    }
  }, {
    key: "render",
    value: function render() {
      var steps = this.props.steps;
      return React.createElement(Timeline, {
        className: "timelines"
      }, this.renderSteps(steps));
    }
  }]);

  return CusTimeline;
}(Component);

export { CusTimeline as default };

==> antd-pro-toolkit-0.6.8.tgz: package/es/Timeline/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import { Timeline } from 'antd';
import { CheckOutlined } from '@ant-design/icons';
import './style';

var CusTimeline =
/*#__PURE__*/
function (_Component) {
  _inherits(CusTimeline, _Component);

  function CusTimeline(props) {
    _classCallCheck(this, CusTimeline);

    return _possibleConstructorReturn(this, _getPrototypeOf(CusTimeline).call(this, props));
  }

  _createClass(CusTimeline, [{
    key: "renderSteps",
    value: function renderSteps(steps) {
      var timelineDot = function timelineDot(index) {
        if (index === 0) {
          return React.createElement("span", {
            className: "dotfirst"
          }, React.createElement(CheckOutlined, null));
        } else {
          return React.createElement("span", {
            className: "dots"
          });
        }
      };

      return steps.map(function (item, index) {
        return React.createElement(Timeline.Item, {
          key: index,
          dot: timelineDot(index)
        }, item.year && React.createElement("div", {
          className: "week"
        }, item.year, "\xA0", item.week), React.createElement("span", {
          className: "messageTime"
        }, item.messageTime), React.createElement("span", {
          className: "statusName"
        }, item.curStatus), React.createElement("span", {
          className: "message"
        }, item.message));
      });
    }
  }, {
    key: "render",
    value: function render() {
      var steps = this.props.steps;
      return React.createElement(Timeline, {
        className: "timelines"
      }, this.renderSteps(steps));
    }
  }]);

  return CusTimeline;
}(Component);

export { CusTimeline as default };
